#
# spec file for package libwps
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{!?make_build:%global make_build make %{?_smp_mflags}}
%define libname libwps-0_4-4
Name:           libwps
Version:        0.4.14
Release:        1.5
Summary:        Library for the Microsoft Works text and spreadsheet formats
License:        LGPL-2.1-or-later AND MPL-2.0
URL:            https://libwps.sourceforge.io/
Source:         https://downloads.sourceforge.net/project/libwps/libwps/libwps-%{version}/libwps-%{version}.tar.xz
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  xz
BuildRequires:  pkgconfig(librevenge-0.0)
%if 0%{?suse_version} >= 1500
BuildRequires:  libboost_headers-devel
%else
BuildRequires:  boost-devel
%endif

%description
libwps is a library for importing the Microsoft Works word processor
and spreadsheet file format.

%package -n %{libname}
Summary:        Library for the Microsoft Works text and spreadsheet formats

%description -n %{libname}
libwps is a library for importing the Microsoft Works word processor
and spreadsheet file format.

%package devel
Summary:        Files for Developing with libwps
Requires:       %{libname} = %{version}

%description devel
libwps is a library for importing the Microsoft Works word processor
and spreadsheet file format.

This package contains the libwps development files.

%package tools
Summary:        Tools for converting the Microsoft Works text and spreadsheet formats

%description tools
Tools to work with the Microsoft Works word processor and spreadsheet
file format, based on libwps.

%prep
%setup -q

%build
export CXXFLAGS="%{optflags} -fvisibility-inlines-hidden"
%configure \
	--disable-silent-rules \
	--disable-werror \
	--disable-static \
	--docdir=%{_docdir}/%{name}
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
mkdir -p %{buildroot}%{_docdir}/%{name}

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%license COPYING.LGPL COPYING.MPL
%{_libdir}/*.so.*

%files devel
%{_libdir}/*.so
%{_libdir}/pkgconfig/libwps*.pc
%{_includedir}/libwps-*

%files tools
%{_bindir}/*
%doc %dir %{_docdir}/%{name}
%doc ChangeLog CREDITS NEWS

%changelog
* Thu Jun 29 2023 Danilo Spinella <danilo.spinella@suse.com>
- Update to 0.4.14:
  * autoupdate configure.ac
  * correct various warnings
* Fri Dec  2 2022 Dirk Müller <dmueller@suse.com>
- update to 0.4.13:
  * Quattro Dos: try to retrieve correctly the spreadsheet's name when creating
    some charts, Quattro: try to avoid potential spreadsheet names clashes +
  * Quattro[dos,wq2]: try to retrieve sheet's name + check that the sheet id in
    formula is not greater than 255, PocketWord: change some comments...
* Fri Jan 28 2022 Fridrich Strba <fstrba@suse.com>
- Fix license header to correspond to SPDX abbreviation
* Wed May 19 2021 Fridrich Strba <fstrba@suse.com>
- Define conditionally make_build to fix build on systems that do
  not have that macro
* Tue Feb 23 2021 Dirk Müller <dmueller@suse.com>
- udpate to 0.4.12:
  - add a minimalist parser for Pocket Word .psw and .pwi files
* Thu Jun 18 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.4.11:
  - XYWrite: add a parser to .fil v2,v4 files
  - wks,wk1: try to correct some problems when
    retrieving cell's reference.
* Thu Nov 15 2018 Tomáš Chvátal <tchvatal@suse.com>
- Version update to 0.4.10:
  * QuattroPro: add parser of .qwp files
  * all: support complex encoding
* Wed May 30 2018 tchvatal@suse.com
- Version update to 0.4.9:
  * QuattroPro: add parser to .wb3 files
  * Multiplan: add parser to DOS v1-v3 files
  * charts: try to retrieve charts in .wk*, .wq* files
  * QuattroPro: add parser to .wb[12] files
  * switch to c++11
  * fuzzing: correct many problems
* Wed Nov 29 2017 tchvatal@suse.com
- Version update to 0.4.7:
  * Many fixes found by fuzzing
* Mon May 15 2017 tchvatal@suse.com
- Version update to 0.4.6:
  * Small bugfixes
* Wed Feb  1 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Fri Jan 13 2017 tchvatal@suse.com
- Version update to to 0.4.5:
  * Additional lotus wk4 support
* Sat Oct 22 2016 jengelh@inai.de
- Remove redundant pkgconfig requires
* Tue Oct 18 2016 tchvatal@suse.com
- Version update to 0.4.4:
  * Few lotus fixes
* Thu May 12 2016 tchvatal@suse.com
- Version update to 0.4.3:
  * Few small fixes, see upstream news for detailed info
* Wed Oct  7 2015 tchvatal@suse.com
- Version update to 0.4.2:
  * Add support for microsoft write files
* Fri Aug 28 2015 tchvatal@suse.com
- Version bump to 0.4.1:
  - QuattroPro: correct a mistake when reading negative cell's position.
  - Fix some Windows build problems.
  - Fix more than 10 hangs when reading damaged files, found with the help
    of american-fuzzy-lop.
  - Performance: improve the sheet's output generation.
* Sat Jun 13 2015 tchvatal@suse.com
- Version bump to 0.4.0:
  - add support for unknown encoding files (ie. DOS file)
  - add potential support for converting Lotus, ... documents,
  - accept to convert all Lotus Wk1 files and Symphony Wk1 files,
  - add support for Lotus Wk3 and Wk4 documents,
  - add support for Quattro Pro Wq1 and Wq2 documents,
  - only in debug mode, add pre-support for Lotus Wk5..., must allow to
    retrieve the main sheets content's with no formatting,
  - add potential support for asking the document's password ( but do nothing )
  - correct some compiler warnings when compiling in debug mode.
* Fri Jan  2 2015 tchvatal@suse.com
- Version bump to 0.3.1:
  - Fix parsing of floating-point numbers in specific cases.
  - Fix several minor issues reported by Coverity and Clang.
  - Check arguments of public functions. Passing NULL no longer causes
    a crash.
  - Use symbol visibility on Linux. The library only exports the public
    functions now.
  - Import @TERM and @CTERM functions (fdo#86241).
  - Handle LICS character encoding in spreadsheets (fdo#87222).
  - Fix a crash when reading a broken file, found with the help of
    american-fuzzy-lop.
* Mon May 26 2014 fstrba@suse.com
- Upgrade to upstream version 0.3.0
  * ABI change
  * Remove dependency on libwpd-devel
  * Add dependency on librevenge-devel
- Added support of Microsoft Works spreadsheets
* Sat Jan 25 2014 tchvatal@suse.com
- Cleanup with spec-cleaner
* Sat Jan 18 2014 crrodriguez@opensuse.org
- build with -fvisibility-inlines-hidden
- Enable verbose build.
* Mon May 27 2013 tchvatal@suse.com
- update to 0.2.9
  - Various coverity and style fixes
  - Add provides line to make rpmlint happy
* Sat Apr 20 2013 tchvatal@suse.com
- Use url download path.
* Fri Apr 19 2013 fridrich.strba@suse.com
- update to 0.2.8
  - Add MPL 2.0+ as license
  - Miscellaneous coverity fixes
  - Add support of text frames and pictures
  - Improvements in table code
  - Read the page orientation
* Tue Nov  6 2012 tchvatal@suse.com
- update to 0.2.7
  - Disable werror explicitely
* Thu May 31 2012 fridrich.strba@suse.com
- upgrade to 0.2.6
  - Boost dependency for shared_ptr
  - Miscellaneous upstream bug fixes and enhancements
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Tue Nov 29 2011 jengelh@medozas.de
- Remove redundant/unwanted tags/section (cf. specfile guidelines)
- Use %%_smp_mflags for parallel building
- Set appropriate package group
* Tue Nov 29 2011 fridrich.strba@suse.com
- upgrade to 0.2.4
  - fix generation of invalid xml due to control characters in
    text stream.
* Wed Sep 28 2011 fridrich.strba@suse.com
- upgrade to 0.2.3
  - Fix miscellaneous crashes due to file-format misunderstanding
  - Fix production of invalid callgraph with documents with footnotes
    and lists.
  - Silence more warnings
- add Laurent Alonso to authors
- remove unneeded patch
* Wed May 18 2011 fstrba@novell.com
- Add libwps-0.2.0-gcc46.patch: fix compilation with gcc 4.6.x
* Wed May  4 2011 fstrba@novell.com
- upgrade to 0.2.2
  - Fix memory leaks and jumps based on uninitialized variable
  - Some feature conversions
  - Silence some warnings
* Thu Mar 24 2011 idoenmez@novell.com
- Add libwps-0.2.0-gcc46.patch: fix compilation with gcc 4.6
* Wed Dec  8 2010 fstrba@novell.com
- Upgrade to a new ABI version
* Wed Oct 22 2008 mrueckert@suse.de
- fix debug_packages_requires define
* Fri Aug  1 2008 ro@suse.de
- fix requires for debuginfo package
* Fri Apr  4 2008 mmarek@suse.cz
- rename the library package to libwps-0_1-1 as required by the
  policy (libwps-0.1.so.1 -> libwps-0_1-1)
- don't version the devel package after discussion with pmladek
  we'll do it only if the need arises
* Wed Apr  2 2008 mmarek@suse.cz
- packaged version 0.1.2, based on work by pmladek
